@@ -13,7 +13,7 @@ use Lemonldap::NG::Portal::_Browser;
 use Cache::FileCache;
 
 our @ISA     = (qw(Lemonldap::NG::Portal::_Browser));
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.6';
 our $initDone;
 
 BEGIN {
@@ -109,7 +109,7 @@ sub extractFormInfo {
     # 3. Check if an OpenID url has been submitted
     else {
         my $tmp = $url;
-        $tmp =~ m#^http//(.*?)/#;
+        $tmp =~ m#^https?://(.*?)/#;
         if ( $tmp =~
             $self->{_reopenIdIDPList} xor $self->{_openIdIDPListIsWhite} )
         {
@@ -278,7 +278,7 @@ L<http://lemonldap-ng.org/>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 =head1 DOWNLOAD
 
